ReadResult

Struct ReadResult 

pub struct ReadResult { /* private fields */ }
Result type for ReadHalf::read operations.

Implementations

Source

impl ReadResult

pub fn bytes_read(&self) -> usize

The number of bytes read.

pub fn fds(&self) -> &[OwnedFd]

The file descriptors received, if any. This is only available with the std feature.

pub fn credentials(&self) -> Option<&PassedCredentials>

The credentials received, if any. This is only available with the std feature and linux target.

pub fn take_fds(&mut self) -> Vec<OwnedFd>

Takes the file descriptors received, leaving an empty list in their place. This is only available with the std feature.

pub fn into_fds(self) -> Vec<OwnedFd>

Consumes this ReadResult and returns the file descriptors received, if any. This is only available with the std feature.

pub fn take_credentials(&mut self) -> Option<PassedCredentials>

Takes the credentials received, leaving None in their place. This is only available with the std feature and linux target.

pub fn into_credentials(self) -> Option<PassedCredentials>

Consumes this ReadResult and returns the credentials received, if any. This is only available with the std feature and linux target.